@@ -3,10 +3,10 @@ package Alien::Libbz2;
 use strict;
 use warnings;
 use 5.008001;
-use parent 'Alien::Base';
+use base 'Alien::Base2';
 
 # ABSTRACT: Build and make available bz2
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
 
 sub alien_helper
@@ -32,7 +32,7 @@ Alien::Libbz2 - Build and make available bz2
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
